templatetags Package
====================

:mod:`patch` Module
-------------------

.. automodule:: permission.templatetags.patch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`permissionif` Module
--------------------------

.. automodule:: permission.templatetags.permissionif
    :members:
    :undoc-members:
    :show-inheritance:

